==> aws-java-sdk-1.1.9-sources.jar: com/amazonaws/services/identitymanagement/model/transform/CreateAccountAliasRequestMarshaller.java <==
/*
 * Copyright 2010-2011 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.identitymanagement.model.transform;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.services.identitymanagement.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.StringUtils;

/**
 * Create Account Alias Request Marshaller
 */
public class CreateAccountAliasRequestMarshaller implements Marshaller<Request<CreateAccountAliasRequest>, CreateAccountAliasRequest> {

    public Request<CreateAccountAliasRequest> marshall(CreateAccountAliasRequest createAccountAliasRequest) {
        Request<CreateAccountAliasRequest> request = new DefaultRequest<CreateAccountAliasRequest>(createAccountAliasRequest, "AmazonIdentityManagement");
        request.addParameter("Action", "CreateAccountAlias");
        request.addParameter("Version", "2010-05-08");
        if (createAccountAliasRequest != null) {
            if (createAccountAliasRequest.getAccountAlias() != null) {
                request.addParameter("AccountAlias", StringUtils.fromString(createAccountAliasRequest.getAccountAlias()));
            }
        }


        return request;
    }
}

==> aws-java-sdk-1.2.14-sources.jar: com/amazonaws/services/identitymanagement/model/transform/CreateAccountAliasRequestMarshaller.java <==
/*
 * Copyright 2010-2011 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 * 
 *  http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.identitymanagement.model.transform;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.amazonaws.AmazonClientException;
import com.amazonaws.Request;
import com.amazonaws.DefaultRequest;
import com.amazonaws.services.identitymanagement.model.*;
import com.amazonaws.transform.Marshaller;
import com.amazonaws.util.StringUtils;

/**
 * Create Account Alias Request Marshaller
 */
public class CreateAccountAliasRequestMarshaller implements Marshaller<Request<CreateAccountAliasRequest>, CreateAccountAliasRequest> {

    public Request<CreateAccountAliasRequest> marshall(CreateAccountAliasRequest createAccountAliasRequest) {

        if (createAccountAliasRequest == null) {
		    throw new AmazonClientException("Invalid argument passed to marshall(...)");
		}

        Request<CreateAccountAliasRequest> request = new DefaultRequest<CreateAccountAliasRequest>(createAccountAliasRequest, "AmazonIdentityManagement");
        request.addParameter("Action", "CreateAccountAlias");
        request.addParameter("Version", "2010-05-08");

        if (createAccountAliasRequest.getAccountAlias() != null) {
            request.addParameter("AccountAlias", StringUtils.fromString(createAccountAliasRequest.getAccountAlias()));
        }


        return request;
    }
}
